const state = {
    show_chismosa: false,
    show_devoluciones: false,
    show_tags: true,
    tags_interactuada: false,
    migas: [{ nombre: 'Pedidos', action: 'pedido/resetear' }],
    canasta_actual: null,
};

const mutations = {
    setCanastaActual(state, { canasta }) {
        state.canasta_actual = canasta;
    },
    toggleChismosa(state) {
        state.show_chismosa = !state.show_chismosa;
    },
    toggleDevoluciones(state) {
        state.show_devoluciones = !state.show_devoluciones;
    },
    toggleTags(state, manual) {
        if (manual)
            state.tags_interactuada = true;
        state.show_tags = !state.show_tags;
    },
    addMiga(state, miga) {
        state.migas.push(miga);
    },
    popUltimaBusqueda(state) {
        if (!state.migas.at(-1).action)
            state.migas.pop();
    },
    reset(state) {
        state.show_chismosa = false;
        state.show_devoluciones = false;
    }
};

const actions = {
    async getCanastaActual({ commit }) {
        const response = await axios.get('/api/canasta-actual');
        commit("setCanastaActual", { canasta: response.data });
    },
    clickMiga({ dispatch }, { miga }) {
        let dropWhile = (array, pred) => {
            let result = array.slice(0);
            while (result.length && pred(result[0])) {
                result = result.slice(1)
            }
            return result;
        }

        dispatch(miga.action, miga.arguments ?? null, { root: true });
        state.migas = dropWhile(state.migas.reverse(),(m => m.nombre !== miga.nombre)).reverse();
    },
    toast(_, { mensaje }) {
        return window.bulmaToast.toast({
            message: mensaje,
            duration: 2000,
            type: 'is-danger',
            position: 'bottom-center',
        });
    },
    error({ dispatch }, { error }) {
        const errorMsg = error.response && error.response.data && error.response.data.message
            ? error.response.data.message
            : error.message;
        dispatch("toast", { mensaje: errorMsg });
    },
    resetear({ commit }) {
        commit("reset");
    },
};

export default {
    namespaced: true,
    state,
    mutations,
    actions,
};
