<?php

use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\URL;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

if (App::environment('production')) {
    URL::forceScheme('https');
}

Auth::routes(['register' => false]);

Route::get('/', 'RouteController@home')->name('home');

Route::middleware(['auth'])->group(function () {
    Route::get('/user/rol', 'UserController@rol')->name('user.rol');
    Route::get('/user/grupo_de_compra', 'UserController@grupoDeCompra');
});

Route::middleware(['auth', 'role:barrio'])->group(function() {
    Route::get('/pedido', 'RouteController@main')->name('pedido');
    Route::get('/pedido/sesion', 'SessionController@fetch');
    Route::post('/pedido/sesion', 'SessionController@store');
    Route::delete('/pedido/sesion', 'SessionController@destroy');
});

Route::get('/admin/login', 'AdminController@show')->name('admin.login');

Route::middleware(['auth', 'role:admin_barrio'])->group(function () {
	Route::get('/admin', 'RouteController@main')->name('admin');

	Route::get('/admin/exportar-planillas-a-pdf/{gdc}', 'AdminController@exportarPedidosAPdf');
	Route::get('/admin/exportar-pedido-a-csv/{gdc}', 'AdminController@exportarPedidoACSV');
	Route::get('/admin/exportar-pedido-con-nucleos-a-csv/{gdc}', 'AdminController@exportarPedidoConNucleosACSV');
});

Route::get('/comisiones/login', 'ComisionesController@show')->name('comisiones.login');

Route::middleware(['auth', 'role:comision'])->group( function() {
    Route::get('/comisiones', 'RouteController@main')->name('comisiones');
    Route::get('/comisiones/pedidos/descargar', 'ComisionesController@descargarPedidos')->name('comisiones.pedidos.descargar');
    Route::get('/comisiones/pedidos/notas', 'ComisionesController@descargarNotas')->name('comisiones.pedidos.descargar');
    Route::get('/comisiones/pedidos/pdf', 'ComisionesController@pdf')->name('comisiones.pedidos.pdf');
    Route::get('/comisiones/canasta/ejemplo', 'ComisionesController@descargarCanastaEjemplo')->name('comisiones.canasta.ejemplo');
    Route::post('/comisiones/canasta', 'ComisionesController@cargarCanasta')->name('comisiones.canasta');
});
